"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CheqdLedgerService = exports.DefaultRPCUrl = void 0;
const sdk_1 = require("@cheqd/sdk");
const core_1 = require("@credo-ts/core");
const CheqdModuleConfig_1 = require("../CheqdModuleConfig");
const identifiers_1 = require("../anoncreds/utils/identifiers");
const didCheqdUtil_1 = require("../dids/didCheqdUtil");
var DefaultRPCUrl;
(function (DefaultRPCUrl) {
    DefaultRPCUrl["Mainnet"] = "https://rpc.cheqd.net";
    DefaultRPCUrl["Testnet"] = "https://rpc.cheqd.network";
})(DefaultRPCUrl = exports.DefaultRPCUrl || (exports.DefaultRPCUrl = {}));
let CheqdLedgerService = class CheqdLedgerService {
    constructor(cheqdSdkModuleConfig) {
        this.networks = cheqdSdkModuleConfig.networks.map((config) => {
            const { network, rpcUrl, cosmosPayerSeed } = config;
            return {
                network,
                rpcUrl: rpcUrl ? rpcUrl : network === sdk_1.CheqdNetwork.Mainnet ? DefaultRPCUrl.Mainnet : DefaultRPCUrl.Testnet,
                cosmosPayerWallet: (0, didCheqdUtil_1.getCosmosPayerWallet)(cosmosPayerSeed),
            };
        });
    }
    async connect() {
        for (const network of this.networks) {
            network.sdk = await (0, sdk_1.createCheqdSDK)({
                modules: [sdk_1.DIDModule, sdk_1.ResourceModule],
                rpcUrl: network.rpcUrl,
                wallet: await network.cosmosPayerWallet.catch((error) => {
                    throw new core_1.AriesFrameworkError(`Error initializing cosmos payer wallet: ${error.message}`, { cause: error });
                }),
            });
        }
    }
    getSdk(did) {
        const parsedDid = (0, identifiers_1.parseCheqdDid)(did);
        if (!parsedDid) {
            throw new Error('Invalid DID');
        }
        if (this.networks.length === 0) {
            throw new Error('No cheqd networks configured');
        }
        const network = this.networks.find((network) => network.network === parsedDid.network);
        if (!network || !network.sdk) {
            throw new Error('Network not configured');
        }
        return network.sdk;
    }
    async create(didPayload, signInputs, versionId, fee) {
        return await this.getSdk(didPayload.id).createDidDocTx(signInputs, didPayload, '', fee, undefined, versionId);
    }
    async update(didPayload, signInputs, versionId, fee) {
        return await this.getSdk(didPayload.id).updateDidDocTx(signInputs, didPayload, '', fee, undefined, versionId);
    }
    async deactivate(didPayload, signInputs, versionId, fee) {
        return await this.getSdk(didPayload.id).deactivateDidDocTx(signInputs, didPayload, '', fee, undefined, versionId);
    }
    async resolve(did, version) {
        return version ? await this.getSdk(did).queryDidDocVersion(did, version) : await this.getSdk(did).queryDidDoc(did);
    }
    async resolveMetadata(did) {
        return await this.getSdk(did).queryAllDidDocVersionsMetadata(did);
    }
    async createResource(did, resourcePayload, signInputs, fee) {
        return await this.getSdk(did).createLinkedResourceTx(signInputs, resourcePayload, '', fee, undefined);
    }
    async resolveResource(did, collectionId, resourceId) {
        return await this.getSdk(did).queryLinkedResource(collectionId, resourceId);
    }
    async resolveCollectionResources(did, collectionId) {
        return await this.getSdk(did).queryLinkedResources(collectionId);
    }
    async resolveResourceMetadata(did, collectionId, resourceId) {
        return await this.getSdk(did).queryLinkedResourceMetadata(collectionId, resourceId);
    }
};
CheqdLedgerService = __decorate([
    (0, core_1.injectable)(),
    __metadata("design:paramtypes", [CheqdModuleConfig_1.CheqdModuleConfig])
], CheqdLedgerService);
exports.CheqdLedgerService = CheqdLedgerService;
//# sourceMappingURL=CheqdLedgerService.js.map